# Guacamole REST API bindings for Python

![PyPI](https://img.shields.io/pypi/v/guacapy)
![PyPI - Downloads](https://img.shields.io/pypi/dm/guacapy)
![PyPI - License](https://img.shields.io/pypi/l/guacapy)
![Python Lint](https://github.com/pschmitt/guacapy/workflows/Python%20Lint/badge.svg)
